A scalar storing the value of the weighted Youden index.
Arguments
truth
The column identifier for the true class results (that is a factor).
estimate
The column identifier for the predicted class results (that is also factor).
sensitivity_weight
A scalar value specifying the weight to put on sensitivity.
Defaults to 0.5 which puts equal weights to sensitivity and specificity.
estimator
One of: "binary", "macro", "macro_weighted", or "micro" to specify the type of averaging to be done.
na_rm
A logical value indicating whether NA values should be stripped before the computation proceeds.
case_weights
The optional column identifier for case weights.
event_level
A single string. Either "first" or "second" to specify which level of truth to consider as the "event".
This argument is only applicable when estimator = "binary".
...
Currently unused.
data
Either a data.frame containing the columns specified by the truth and estimate
arguments, or a table/matrix where the true class results should be in the columns of the table.